@@ -171,7 +171,7 @@ ZI_LIST_NODES_ABSOLUTE, ZI_LIST_NODES_LEAFSONLY, ZI_LIST_NODES_SETTINGSONLY.
 =head2 GetDemodSample
 
  my $hash_ref = $connection->GetDemodSample($path);
- # keys: timeStamp, x, y, frequency, phase, dioBits, trigger, auxIn0, auIn1
+ # keys: timeStamp, x, y, frequency, phase, dioBits, trigger, auxIn0, auxIn1
  
 =head2 GetDIOSample
 
@@ -185,27 +185,27 @@ ZI_LIST_NODES_ABSOLUTE, ZI_LIST_NODES_LEAFSONLY, ZI_LIST_NODES_SETTINGSONLY.
 
 =head2 SetValueD
 
- $connection->SetValueD($double);
+ $connection->SetValueD($path, $double);
 
 =head2 SetValueI
 
- $connection->SetValueI($integer);
+ $connection->SetValueI($path, $integer);
 
 =head2 SetValueB
 
- $connection->SetValueB($byte_string);
+ $connection->SetValueB($path, $byte_string);
 
 =head2 SyncSetValueD
 
- my $set_value = $connection->SyncSetValueD($double);
+ my $set_value = $connection->SyncSetValueD($path, $double);
 
 =head2 SyncSetValueI
 
- my $set_value = $connection->SyncSetValueI($integer);
+ my $set_value = $connection->SyncSetValueI($path, $integer);
 
 =head2 SyncSetValueB
 
- my $set_value = $connection->SyncSetValueB($byte_array);
+ my $set_value = $connection->SyncSetValueB($path, $byte_array);
 
 =head2 Sync
 
@@ -268,7 +268,7 @@ at your option, any later version of Perl 5 you may have available.
 
 
 package Lab::Zhinst;
-$Lab::Zhinst::VERSION = '0.04';
+$Lab::Zhinst::VERSION = '0.05';
 use strict;
 use warnings;
 use Carp;
